@@ -4,8 +4,8 @@ use core::ptr::{null, null_mut};
 
 use crate::{
     cstring, error, error_ref_mut, notcurses_init, rstring, NcAlign, NcBlitter, NcChannelPair,
-    NcDimension, NcEgc, NcError, NcFile, NcInput, NcLogLevel, NcPlane, NcResult, NcScale,
-    NcSignalSet, NcStats, NcStyleMask, NcTime, Notcurses, NotcursesOptions,
+    NcDimension, NcEgc, NcError, NcFile, NcInput, NcLogLevel, Notcurses, NotcursesOptions,
+    NcPlane, NcResult, NcScale, NcSignalSet, NcStats, NcStyleMask, NcTime,
     NCOPTION_NO_ALTERNATE_SCREEN, NCOPTION_SUPPRESS_BANNERS, NCRESULT_ERR,
 };
 
@@ -85,38 +85,35 @@ impl NotcursesOptions {
 
 /// # `Notcurses` Constructors
 impl Notcurses {
-    /// Returns a Notcurses context (without banners).
+    /// New Notcurses (without banners).
     pub fn new<'a>() -> NcResult<&'a mut Notcurses> {
         Self::with_flags(NCOPTION_SUPPRESS_BANNERS)
     }
 
-    /// Returns a Notcurses context, with banners. The default in the C library.
+    /// New Notcurses, with banners.
+    ///
+    /// This is the default in the C library.
     pub fn with_banners<'a>() -> NcResult<&'a mut Notcurses> {
         Self::with_flags(0)
     }
 
-    /// Returns a Notcurses context, without an alternate screen (nor banners).
+    /// New Notcurses, without an alternate screen (nor banners).
     pub fn without_altscreen<'a>() -> NcResult<&'a mut Notcurses> {
-        Self::with_flags(NCOPTION_NO_ALTERNATE_SCREEN)
-    }
-
-    /// Returns a Notcurses context, without an alternate screen, with banners.
-    pub fn without_altscreen_nor_banners<'a>() -> NcResult<&'a mut Notcurses> {
         Self::with_flags(NCOPTION_NO_ALTERNATE_SCREEN | NCOPTION_SUPPRESS_BANNERS)
     }
 
-    /// Returns a Notcurses context, expects [NotcursesOptions].
+    /// New Notcurses, expects `NCOPTION_*` flags.
     pub fn with_flags<'a>(flags: u64) -> NcResult<&'a mut Notcurses> {
         Self::with_options(NotcursesOptions::with_flags(flags))
     }
 
-    /// Returns a Notcurses context, expects [NotcursesOptions].
+    /// New Notcurses, expects [NotcursesOptions].
     pub fn with_options<'a>(options: NotcursesOptions) -> NcResult<&'a mut Notcurses> {
         let res = unsafe { notcurses_init(&options, null_mut()) };
         error_ref_mut![res, "Notcurses.with_options()"]
     }
 
-    /// Returns a Notcurses context. Expects [NcLogLevel] and flags.
+    /// New Notcurses, expects [NcLogLevel] and flags.
     pub fn with_debug<'a>(loglevel: NcLogLevel, flags: u64) -> NcResult<&'a mut Notcurses> {
         Self::with_options(NotcursesOptions::with_all_options(
             loglevel, 0, 0, 0, 0, flags,
@@ -133,6 +130,8 @@ impl Notcurses {
     /// [NCALIGN_UNALIGNED][crate::NCALIGN_UNALIGNED] or invalid [NcAlign].
     ///
     /// *C style function: [notcurses_align()][crate::notcurses_align].*
+    //
+    // TODO: handle error rightfully.
     pub fn align(availcols: NcDimension, align: NcAlign, cols: NcDimension) -> NcResult<()> {
         error![crate::notcurses_align(availcols, align, cols)]
     }
@@ -539,6 +538,8 @@ impl Notcurses {
         }
     }
 
+    // TODO: decide what to do with these two:
+    //
     // /// [notcurses_stdplane()][crate::notcurses_stdplane], plus free bonus
     // /// dimensions written to non-NULL y/x!
     // ///
@@ -571,11 +572,8 @@ impl Notcurses {
     /// uppermost, leftmost cell.
     ///
     /// *C style function: [notcurses_stdplane()][crate::notcurses_stdplane].*
-    pub fn stdplane<'a>(&mut self) -> NcResult<&'a mut NcPlane> {
-        error_ref_mut![
-            unsafe { crate::notcurses_stdplane(self) },
-            "Notcurses.stdplane()"
-        ]
+    pub fn stdplane<'a>(&mut self) -> &'a mut NcPlane {
+            unsafe { &mut *crate::notcurses_stdplane(self) }
     }
 
     /// Returns a reference to the standard [NcPlane] for this terminal.
@@ -635,7 +633,7 @@ impl Notcurses {
         unsafe { &mut *crate::notcurses_top(self) }
     }
 
-    /// Returns a human-readable string describing the running Notcurses version.
+    /// Returns a human-readable string describing the running notcurses version.
     ///
     /// *C style function: [notcurses_version()][crate::notcurses_version].*
     pub fn version() -> String {
