@@ -67,16 +67,17 @@ mod test;
 mod helpers;
 mod methods;
 mod reimplemented;
+mod wrapper;
 
 #[allow(unused_imports)]
 pub(crate) use helpers::*;
 pub use reimplemented::*;
+pub use wrapper::*;
 
-/// The main struct of the TUI library (full mode)
-///
 /// Notcurses builds atop the terminfo abstraction layer to
 /// provide reasonably portable vivid character displays.
 ///
+/// This is the internal type safely wrapped by [FullMode].
 pub type Notcurses = crate::bindings::ffi::notcurses;
 
 /// Options struct for [`Notcurses`]
