@@ -1,4 +1,4 @@
-use crate::{NcDimension, NcOffset, NcPlane, NcPlaneOptions, Notcurses};
+use crate::{NcDimension, Notcurses, NcOffset, NcPlane, NcPlaneOptions};
 
 /// Helper function for a new NcPlane on C style tests.
 #[allow(dead_code)]
