@@ -135,6 +135,23 @@ fetch_x_props(fetched_info* fi){
   return 0;
 }
 
+// Given a filename, check for its existence in the directories specified by
+// https://specifications.freedesktop.org/icon-theme-spec/latest/ar01s03.html.
+// Returns NULL if no such file can be found. Return value is heap-allocated.
+static char *
+get_xdg_logo(const char *spec){
+  char logopath[PATH_MAX + 1]; // FIXME
+  int s = snprintf(logopath, sizeof(logopath) - 1, "%s/%s", "/usr/share/pixmaps/", spec);
+  if(s < 0 || (size_t)s >= sizeof(logopath)){
+    return NULL;
+  }
+  if(access(logopath, F_OK) == 0){
+    return strdup(logopath);
+  }
+  return NULL;
+}
+
+// FIXME deal more forgivingly with quotation marks
 static const distro_info*
 linux_ncneofetch(fetched_info* fi){
   FILE* osinfo = fopen("/etc/os-release", "re");
@@ -146,13 +163,13 @@ linux_ncneofetch(fetched_info* fi){
   while(fgets(buf, sizeof(buf), osinfo)){
 #define PRETTY "PRETTY_NAME=\""
 #define ID "ID=" // no quotes on this one
-#define LOGO "LOGO=" // nor here
+#define LOGOQ "LOGO=\""
+#define LOGO "LOGO=" // handle LOGO sans quotes
     if(strncmp(buf, ID, strlen(ID)) == 0){
       char* nl = strchr(buf + strlen(ID), '\n');
       if(nl){
         *nl = '\0';
         distro = strdup(buf + strlen(ID));
-        break;
       }
     }else if(!fi->distro_pretty && strncmp(buf, PRETTY, strlen(PRETTY)) == 0){
       char* nl = strchr(buf + strlen(PRETTY), '"');
@@ -160,15 +177,22 @@ linux_ncneofetch(fetched_info* fi){
         *nl = '\0';
         fi->distro_pretty = strdup(buf + strlen(PRETTY));
       }
-    }else if(!fi->logo && strncmp(buf, LOGO, strlen(LOGO)) == 0){
-      char* nl = strchr(buf + strlen(LOGO), '"');
+    }else if(!fi->logo && strncmp(buf, LOGOQ, strlen(LOGOQ)) == 0){
+      char* nl = strchr(buf + strlen(LOGOQ), '"');
       if(nl){
         *nl = '\0';
-        // FIXME need directory (https://specifications.freedesktop.org/icon-theme-spec/latest/ar01s03.html)
-        fi->logo = strdup(buf + strlen(LOGO));
+        fi->logo = get_xdg_logo(buf + strlen(LOGOQ));
+      }
+    }else if(!fi->logo && strncmp(buf, LOGO, strlen(LOGO)) == 0){
+      char* nl = strchr(buf + strlen(LOGO), '\n');
+      if(nl){
+        *nl = '\0';
+        fi->logo = get_xdg_logo(buf + strlen(LOGO));
       }
     }
   }
+#undef LOGO
+#undef LOGOQ
 #undef ID
 #undef PRETTY
   fclose(osinfo);
@@ -318,13 +342,8 @@ place_infoplane(struct ncdirect* ncd, int planeheight){
 }
 
 static int
-infoplane(struct ncdirect* ncd, const fetched_info* fi){
-  const int planeheight = 8;
+infoplane_notcurses(struct notcurses* nc, const fetched_info* fi, int planeheight){
   const int planewidth = 60;
-  struct notcurses* nc = place_infoplane(ncd, planeheight);
-  if(nc == NULL){
-    return -1;
-  }
   int dimy;
   struct ncplane* std = notcurses_stddim_yx(nc, &dimy, NULL);
   struct ncplane_options nopts = {
@@ -413,26 +432,40 @@ infoplane(struct ncdirect* ncd, const fetched_info* fi){
   if(notcurses_render(nc)){
     return -1;
   }
-  if(notcurses_stop(nc)){
+  return 0;
+}
+
+static int
+infoplane(struct ncdirect* ncd, const fetched_info* fi){
+  const int planeheight = 8;
+  struct notcurses* nc = place_infoplane(ncd, planeheight);
+  if(nc == NULL){
     return -1;
   }
-  return 0;
+  int r = infoplane_notcurses(nc, fi, planeheight);
+  r |= notcurses_stop(nc);
+  return r;
 }
 
 struct marshal {
   struct ncdirect* nc;
   const distro_info* dinfo;
+  const char* logo; // read from /etc/os-release, may be NULL
 };
 
 static void*
 display_thread(void* vmarshal){
   struct marshal* m = vmarshal;
   drawpalette(m->nc);
-  if(m->dinfo){
-    // FIXME check for logo in fetched_info
+  if(m->logo){
+    if(ncdirect_render_image(m->nc, m->logo, NCALIGN_CENTER,
+                             NCBLIT_DEFAULT, NCSCALE_SCALE_HIRES)){
+      return NULL;
+    }
+  }else if(m->dinfo){
     if(m->dinfo->logofile){
       if(ncdirect_render_image(m->nc, m->dinfo->logofile, NCALIGN_CENTER,
-                               NCBLIT_2x2, NCSCALE_SCALE)){
+                               NCBLIT_DEFAULT, NCSCALE_SCALE_HIRES)){
         return NULL;
       }
     }
@@ -459,6 +492,7 @@ ncneofetch(struct ncdirect* nc){
   struct marshal display_marshal = {
     .nc = nc,
     .dinfo = fi.distro,
+    .logo = fi.logo,
   };
   pthread_t tid;
   const bool launched = !pthread_create(&tid, NULL, display_thread, &display_marshal);
