@@ -26,7 +26,11 @@ ncdirect_bg_default_p(const struct ncdirect* nc){
 
 int ncdirect_putstr(ncdirect* nc, uint64_t channels, const char* utf8){
   if(channels_fg_default_p(channels)){
-    if(ncdirect_fg_default_p(nc)){
+    if(ncdirect_set_fg_default(nc)){
+      return -1;
+    }
+  }else if(channels_fg_palindex_p(channels)){
+    if(ncdirect_set_fg_palindex(nc, channels_fg_palindex(channels))){
       return -1;
     }
   }else if(ncdirect_set_fg_rgb(nc, channels_fg_rgb(channels))){
@@ -36,6 +40,10 @@ int ncdirect_putstr(ncdirect* nc, uint64_t channels, const char* utf8){
     if(ncdirect_set_bg_default(nc)){
       return -1;
     }
+  }else if(channels_bg_palindex_p(channels)){
+    if(ncdirect_set_bg_palindex(nc, channels_bg_palindex(channels))){
+      return -1;
+    }
   }else if(ncdirect_set_bg_rgb(nc, channels_bg_rgb(channels))){
     return -1;
   }
@@ -529,12 +537,17 @@ int ncdirect_render_image(ncdirect* n, const char* file, ncalign_e align,
   return ncdirect_raster_frame(n, faken, align);
 }
 
-// FIXME need to update channels
 int ncdirect_set_fg_palindex(ncdirect* nc, int pidx){
+  if(channels_set_fg_palindex(&nc->channels, pidx) < 0){
+    return -1;
+  }
   return term_emit("setaf", tiparm(nc->tcache.setaf, pidx), nc->ttyfp, false);
 }
 
 int ncdirect_set_bg_palindex(ncdirect* nc, int pidx){
+  if(channels_set_bg_palindex(&nc->channels, pidx) < 0){
+    return -1;
+  }
   return term_emit("setab", tiparm(nc->tcache.setab, pidx), nc->ttyfp, false);
 }
 
@@ -579,8 +592,33 @@ int get_controlling_tty(FILE* ttyfp){
   return open(cbuf, O_RDWR | O_CLOEXEC);
 }
 
+static int
+ncdirect_stop_minimal(void* vnc){
+  ncdirect* nc = static_cast<ncdirect*>(vnc);
+  int ret = drop_signals(nc);
+  if(nc->tcache.op && term_emit("op", nc->tcache.op, nc->ttyfp, true)){
+    ret = -1;
+  }
+  if(nc->tcache.sgr0 && term_emit("sgr0", nc->tcache.sgr0, nc->ttyfp, true)){
+    ret = -1;
+  }
+  if(nc->tcache.oc && term_emit("oc", nc->tcache.oc, nc->ttyfp, true)){
+    ret = -1;
+  }
+  if(nc->ctermfd >= 0){
+    if(nc->tcache.cnorm && tty_emit("cnorm", nc->tcache.cnorm, nc->ctermfd)){
+      ret = -1;
+    }
+    if(!(nc->flags & NCDIRECT_OPTION_INHIBIT_CBREAK)){
+      ret |= tcsetattr(nc->ctermfd, TCSANOW, &nc->tpreserved);
+    }
+    ret |= close(nc->ctermfd);
+  }
+  return ret;
+}
+
 ncdirect* ncdirect_init(const char* termtype, FILE* outfp, uint64_t flags){
-  if(flags > (NCDIRECT_OPTION_INHIBIT_CBREAK << 1)){ // allow them through with warning
+  if(flags > (NCDIRECT_OPTION_NO_QUIT_SIGHANDLERS << 1)){ // allow them through with warning
     logwarn((struct notcurses*)NULL, "Passed unsupported flags 0x%016jx\n", (uintmax_t)flags);
   }
   if(outfp == nullptr){
@@ -600,6 +638,11 @@ ncdirect* ncdirect_init(const char* termtype, FILE* outfp, uint64_t flags){
   if(encoding && strcmp(encoding, "UTF-8") == 0){
     ret->utf8 = true;
   }
+  if(setup_signals(ret, (flags & NCDIRECT_OPTION_NO_QUIT_SIGHANDLERS),
+                   true, ncdirect_stop_minimal)){
+    delete ret;
+    return nullptr;
+  }
   // we don't need a controlling tty for everything we do; allow a failure here
   if((ret->ctermfd = get_controlling_tty(ret->ttyfp)) >= 0){
     if(!(flags & NCDIRECT_OPTION_INHIBIT_CBREAK)){
@@ -638,6 +681,7 @@ err:
       tcsetattr(ret->ctermfd, TCSANOW, &ret->tpreserved);
     }
   }
+  drop_signals(ret);
   delete(ret);
   return nullptr;
 }
@@ -645,24 +689,7 @@ err:
 int ncdirect_stop(ncdirect* nc){
   int ret = 0;
   if(nc){
-    if(nc->tcache.op && term_emit("op", nc->tcache.op, nc->ttyfp, true)){
-      ret = -1;
-    }
-    if(nc->tcache.sgr0 && term_emit("sgr0", nc->tcache.sgr0, nc->ttyfp, true)){
-      ret = -1;
-    }
-    if(nc->tcache.oc && term_emit("oc", nc->tcache.oc, nc->ttyfp, true)){
-      ret = -1;
-    }
-    if(nc->ctermfd >= 0){
-      if(nc->tcache.cnorm && tty_emit("cnorm", nc->tcache.cnorm, nc->ctermfd)){
-        ret = -1;
-      }
-      if(!(nc->flags & NCDIRECT_OPTION_INHIBIT_CBREAK)){
-        ret |= tcsetattr(nc->ctermfd, TCSANOW, &nc->tpreserved);
-      }
-      ret |= close(nc->ctermfd);
-    }
+    ret |= ncdirect_stop_minimal(nc);
     input_free_esctrie(&nc->input.inputescapes);
     delete(nc);
   }
