@@ -606,11 +606,6 @@ ncplane_cell_ref_yx(ncplane* n, int y, int x){
   return &n->fb[nfbcellidx(n, y, x)];
 }
 
-static inline void
-cell_set_wide(nccell* c){
-  c->channels |= CELL_WIDEASIAN_MASK;
-}
-
 #define NANOSECS_IN_SEC 1000000000
 
 static inline uint64_t
@@ -673,8 +668,6 @@ cell_duplicate_far(egcpool* tpool, nccell* targ, const ncplane* splane, const nc
     return 0;
   }
   const char* egc = cell_extended_gcluster(splane, c);
-  // FIXME we could eliminate this strlen() with a cell_extended_gcluster_len()
-  // that returned the length, combined with O(1) length for inlined EGCs...
   size_t ulen = strlen(egc);
   int eoffset = egcpool_stash(tpool, egc, ulen);
   if(eoffset < 0){
@@ -1000,16 +993,10 @@ pool_blit_direct(egcpool* pool, nccell* c, const char* gcluster, int bytes, int
 static inline int
 pool_load_direct(egcpool* pool, nccell* c, const char* gcluster, int bytes, int cols){
   char* rtl = NULL;
-  c->width = cols - 1;
-  if(cols < 2){
-    c->channels &= ~CELL_WIDEASIAN_MASK;
-    if(bytes == 3 && memcmp(gcluster, "\xe2\x96\x88", 4) == 0){
-      c->channels |= CELL_NOBACKGROUND_MASK;
-    }else{
-      c->channels &= ~CELL_NOBACKGROUND_MASK;
-    }
+  c->width = cols;
+  if(bytes == 3 && memcmp(gcluster, "\xe2\x96\x88", 4) == 0){
+    c->channels |= CELL_NOBACKGROUND_MASK;
   }else{
-    c->channels |= CELL_WIDEASIAN_MASK;
     c->channels &= ~CELL_NOBACKGROUND_MASK;
   }
   if(bytes >= 0){
@@ -1090,6 +1077,10 @@ int cbreak_mode(int ttyfd, const struct termios* tpreserved);
 // If you only want to check n < 4 channels, just duplicate one.
 bool check_gradient_args(uint64_t ul, uint64_t ur, uint64_t bl, uint64_t br);
 
+int setup_signals(void* nc, bool no_quit_sigs, bool no_winch_sig,
+                  int(*handler)(void*));
+int drop_signals(void* nc);
+
 #ifdef __cplusplus
 }
 #endif
