@@ -13,11 +13,9 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <unistr.h>
-#include <signal.h>
 #include <locale.h>
 #include <uniwbrk.h>
 #include <langinfo.h>
-#include <stdatomic.h>
 #include <sys/ioctl.h>
 #include <notcurses/direct.h>
 
@@ -36,21 +34,6 @@ void notcurses_version_components(int* major, int* minor, int* patch, int* tweak
   *tweak = atoi(NOTCURSES_VERSION_TWEAK);
 }
 
-// only one notcurses object can be the target of signal handlers, due to their
-// process-wide nature.
-static notcurses* _Atomic signal_nc = ATOMIC_VAR_INIT(NULL); // ugh
-static void (*signal_sa_handler)(int); // stashed signal handler we replaced
-
-static int
-drop_signals(notcurses* nc){
-  notcurses* old = nc;
-  if(!atomic_compare_exchange_strong(&signal_nc, &old, NULL)){
-    fprintf(stderr, "Couldn't drop signals: %p != %p\n", old, nc);
-    return -1;
-  }
-  return 0;
-}
-
 // reset the current colors, styles, and palette. called on startup (to purge
 // any preexisting styling) and shutdown (to not affect further programs).
 static int
@@ -73,9 +56,9 @@ reset_term_attributes(notcurses* nc){
 // the end of the line for fatal signal handlers. notcurses_stop() will go on
 // to tear down and account for internal structures.
 static int
-notcurses_stop_minimal(notcurses* nc){
-  int ret = 0;
-  drop_signals(nc);
+notcurses_stop_minimal(void* vnc){
+  notcurses* nc = vnc;
+  int ret = drop_signals(nc);
   // be sure to write the restoration sequences *prior* to running rmcup, as
   // they apply to the screen (alternate or otherwise) we're actually using.
   ret |= reset_term_attributes(nc);
@@ -93,66 +76,6 @@ notcurses_stop_minimal(notcurses* nc){
   return ret;
 }
 
-// this wildly unsafe handler will attempt to restore the screen upon receipt
-// of SIG{INT, SEGV, ABRT, QUIT, TERM}. godspeed you, black emperor!
-static void
-fatal_handler(int signo){
-  notcurses* nc = atomic_load(&signal_nc);
-  if(nc){
-    notcurses_stop_minimal(nc);
-    if(signal_sa_handler){
-      signal_sa_handler(signo);
-    }
-    raise(signo);
-  }
-}
-
-static int
-setup_signals(notcurses* nc, bool no_quit_sigs, bool no_winch_sig){
-  notcurses* expected = NULL;
-  struct sigaction oldact;
-  struct sigaction sa;
-
-  if(!atomic_compare_exchange_strong(&signal_nc, &expected, nc)){
-    fprintf(stderr, "%p is already registered for signals\n", expected);
-    return -1;
-  }
-  if(!no_winch_sig){
-    memset(&sa, 0, sizeof(sa));
-    sa.sa_handler = sigwinch_handler;
-    if(sigaction(SIGWINCH, &sa, NULL)){
-      atomic_store(&signal_nc, NULL);
-      fprintf(stderr, "Error installing SIGWINCH handler (%s)\n",
-              strerror(errno));
-      return -1;
-    }
-  }
-  if(!no_quit_sigs){
-    memset(&sa, 0, sizeof(sa));
-    sa.sa_handler = fatal_handler;
-    sigaddset(&sa.sa_mask, SIGINT);
-    sigaddset(&sa.sa_mask, SIGQUIT);
-    sigaddset(&sa.sa_mask, SIGSEGV);
-    sigaddset(&sa.sa_mask, SIGABRT);
-    sigaddset(&sa.sa_mask, SIGTERM);
-    sa.sa_flags = SA_RESETHAND; // don't try twice
-    int ret = 0;
-    ret |= sigaction(SIGINT, &sa, &oldact);
-    ret |= sigaction(SIGQUIT, &sa, &oldact);
-    ret |= sigaction(SIGSEGV, &sa, &oldact);
-    ret |= sigaction(SIGABRT, &sa, &oldact);
-    ret |= sigaction(SIGTERM, &sa, &oldact);
-    if(ret){
-      atomic_store(&signal_nc, NULL);
-      fprintf(stderr, "Error installing fatal signal handlers (%s)\n",
-              strerror(errno));
-      return -1;
-    }
-    signal_sa_handler = oldact.sa_handler;
-  }
-  return 0;
-}
-
 // make a heap-allocated wchar_t expansion of the multibyte string at s
 wchar_t* wchar_from_utf8(const char* s){
   mbstate_t ps;
@@ -1096,9 +1019,9 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   }else{
     fprintf(stderr, "Defaulting to %dx%d (output is not to a terminal)\n", DEFAULT_ROWS, DEFAULT_COLS);
   }
-  if(setup_signals(ret,
-                   (opts->flags & NCOPTION_NO_QUIT_SIGHANDLERS),
-                   (opts->flags & NCOPTION_NO_WINCH_SIGHANDLER))){
+  if(setup_signals(ret, (opts->flags & NCOPTION_NO_QUIT_SIGHANDLERS),
+                   (opts->flags & NCOPTION_NO_WINCH_SIGHANDLER),
+                   notcurses_stop_minimal)){
     // don't treat failure here as an error. it screws up unit tests, and one
     // day we'll need support multiple notcurses contexts. FIXME
   }
@@ -1272,11 +1195,11 @@ int notcurses_stop(notcurses* nc){
                 nc->stashstats.render_bytes / (double)nc->stashstats.renders / 1024);
       }
       if(nc->stashstats.renders || nc->stashstats.failed_renders){
-        fprintf(stderr, "%.1f theoretical FPS, %ju failed render%s, %ju refresh%s\n",
-                nc->stashstats.renders ?
-                  NANOSECS_IN_SEC * (double)nc->stashstats.renders / nc->stashstats.render_ns : 0.0,
+        fprintf(stderr, "%ju failed render%s, %ju failed write%s, %ju refresh%s\n",
                 nc->stashstats.failed_renders,
                 nc->stashstats.failed_renders == 1 ? "" : "s",
+                nc->stashstats.failed_writeouts,
+                nc->stashstats.failed_writeouts == 1 ? "" : "s",
                 nc->stashstats.refreshes,
                 nc->stashstats.refreshes == 1 ? "" : "es");
         fprintf(stderr, "RGB emits:elides: def %ju:%ju fg %ju:%ju bg %ju:%ju\n",
@@ -1390,6 +1313,9 @@ int ncplane_set_bg_palindex(ncplane* n, int idx){
 }
 
 int ncplane_set_base_cell(ncplane* ncp, const nccell* c){
+  if(cell_wide_right_p(c)){
+    return -1;
+  }
   return cell_duplicate(ncp, &ncp->basecell, c);
 }
 
@@ -1590,16 +1516,19 @@ ncplane_put(ncplane* n, int y, int x, const char* egc, int cols,
     return -1;
   }
 //fprintf(stderr, "%08x %016lx %c %d %d\n", targ->gcluster, targ->channels, cell_double_wide_p(targ) ? 'D' : 'd', bytes, cols);
-  if(cols > 1){ // must set our right wide, and check for further damage
-    nccell* candidate = &n->fb[nfbcellidx(n, n->y, n->x + 1)];
+  // must set our right hand sides wide, and check for further damage
+  ++n->x;
+  for(int i = 1 ; i < cols ; ++i){
+    nccell* candidate = &n->fb[nfbcellidx(n, n->y, n->x)];
     if(cell_wide_left_p(candidate)){
-      cell_obliterate(n, &n->fb[nfbcellidx(n, n->y, n->x + 2)]);
+      cell_obliterate(n, &n->fb[nfbcellidx(n, n->y, n->x + 1)]);
     }
     cell_release(n, candidate);
     candidate->channels = targ->channels;
     candidate->stylemask = targ->stylemask;
+    candidate->width = targ->width;
+    ++n->x;
   }
-  n->x += cols;
   return cols;
 }
 
