@@ -284,12 +284,13 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
             // are we on the last column of the real screen? if so, 0x20 us
             if(absx >= dstlenx - 1){
               targc->gcluster = htole(' ');
+              targc->width = 1;
             // is the next cell occupied? if so, 0x20 us
             }else if(crender[1].c.gcluster){
 //fprintf(stderr, "NULLING out %d/%d (%d/%d) due to %u\n", y, x, absy, absx, crender[1].c.gcluster);
               targc->gcluster = htole(' ');
+              targc->width = 1;
             }else{
-              cell_set_wide(targc);
               targc->stylemask = vis->stylemask;
               targc->width = vis->width;
             }
@@ -299,9 +300,8 @@ paint(const ncplane* p, struct crender* rvec, int dstleny, int dstlenx,
           }
           crender->p = p;
         }else if(cell_wide_right_p(vis)){
-          cell_set_wide(targc);
           crender->p = p;
-          targc->width = vis->width;
+          targc->width = 0;
         }
       }
 
@@ -391,24 +391,29 @@ lock_in_highcontrast(nccell* targc, struct crender* crender){
   }
 }
 
+// Postpaint a single cell (multiple if it is a multicolumn EGC). This means
+// checking for and locking in high-contrast, checking for damage, and updating
+// 'lastframe' for any cells which are damaged.
 static inline void
 postpaint_cell(nccell* lastframe, int dimx, struct crender* crender,
-               egcpool* pool, int y, int x){
+               egcpool* pool, int y, int* x){
   nccell* targc = &crender->c;
   lock_in_highcontrast(targc, crender);
-  nccell* prevcell = &lastframe[fbcellidx(y, dimx, x)];
+  nccell* prevcell = &lastframe[fbcellidx(y, dimx, *x)];
   if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc) > 0){
     crender->damaged = true;
-    if(cell_wide_left_p(targc)){
+    assert(!cell_wide_right_p(targc));
+    const int width = targc->width;
+    for(int i = 1 ; i < width ; ++i){
       const ncplane* tmpp = crender->p;
       ++crender;
       crender->p = tmpp;
-      ++x;
+      ++*x;
       ++prevcell;
-      ++targc;
+      targc = &crender->c;
       targc->gcluster = 0;
-      targc->channels = crender[-1].c.channels;
-      targc->stylemask = crender[-1].c.stylemask;
+      targc->channels = crender[-i].c.channels;
+      targc->stylemask = crender[-i].c.stylemask;
       if(cellcmp_and_dupfar(pool, prevcell, crender->p, targc) > 0){
         crender->damaged = true;
       }
@@ -416,6 +421,7 @@ postpaint_cell(nccell* lastframe, int dimx, struct crender* crender,
   }
 }
 
+
 // iterate over the rendered frame, adjusting the foreground colors for any
 // cells marked CELL_ALPHA_HIGHCONTRAST, and clearing any cell covered by a
 // wide glyph to its left.
@@ -430,7 +436,7 @@ postpaint(nccell* lastframe, int dimy, int dimx, struct crender* rvec, egcpool*
   for(int y = 0 ; y < dimy ; ++y){
     for(int x = 0 ; x < dimx ; ++x){
       struct crender* crender = &rvec[fbcellidx(y, dimx, x)];
-      postpaint_cell(lastframe, dimx, crender, pool, y, x);
+      postpaint_cell(lastframe, dimx, crender, pool, y, &x);
     }
   }
 }
@@ -832,7 +838,7 @@ raster_defaults(notcurses* nc, bool fgdef, bool bgdef, FILE* out){
 // *become* the last frame rasterized.
 static int
 notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
-  struct crender* rvec = p->crender;
+  const struct crender* rvec = p->crender;
   int y, x;
   fseeko(out, 0, SEEK_SET);
   // we only need to emit a coordinate if it was damaged. the damagemap is a
@@ -849,7 +855,6 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
       const size_t damageidx = innery * nc->lfdimx + innerx;
       unsigned r, g, b, br, bg, bb, palfg, palbg;
       const nccell* srccell = &nc->lastframe[damageidx];
-      postpaint_cell(nc->lastframe, p->dimx, &rvec[damageidx], &nc->pool, y, x);
       if(!rvec[damageidx].damaged){
         // no need to emit a cell; what we rendered appears to already be
         // here. no updates are performed to elision state nor lastframe.
@@ -963,12 +968,15 @@ notcurses_rasterize_inner(notcurses* nc, const ncpile* p, FILE* out){
           nc->rstate.bgdefelidable = false;
           nc->rstate.bgpalelidable = false;
         }
-//fprintf(stderr, "RAST %08x [%s] to %d/%d cols: %u %016lx\n", srccell->gcluster, pool_extended_gcluster(&nc->pool, srccell), y, x, srccell->width + 1, srccell->channels);
+//fprintf(stderr, "RAST %08x [%s] to %d/%d cols: %u %016lx\n", srccell->gcluster, pool_extended_gcluster(&nc->pool, srccell), y, x, srccell->width, srccell->channels);
         if(term_putc(out, &nc->pool, srccell)){
           return -1;
         }
-        nc->rstate.x += srccell->width + 1;
-        x += srccell->width;
+        ++nc->rstate.x;
+        if(srccell->width >= 2){
+          x += srccell->width - 1;
+          nc->rstate.x += srccell->width - 1;
+        }
       }
 //fprintf(stderr, "damageidx: %ld\n", damageidx);
     }
@@ -1129,6 +1137,9 @@ int ncpile_rasterize(ncplane* n){
   clock_gettime(CLOCK_MONOTONIC, &start);
   const ncpile* pile = ncplane_pile(n);
   struct notcurses* nc = ncplane_notcurses(n);
+  const int miny = pile->dimy < nc->lfdimy ? pile->dimy : nc->lfdimy;
+  const int minx = pile->dimx < nc->lfdimx ? pile->dimx : nc->lfdimx;
+  postpaint(nc->lastframe, miny, minx, pile->crender, &nc->pool);
   int bytes = notcurses_rasterize(nc, pile, nc->rstate.mstreamfp);
   // accepts -1 as an indication of failure
   update_render_bytes(&nc->stats, bytes);
