@@ -15,7 +15,7 @@ auto ncvisual_geom(const notcurses* nc, const ncvisual* n,
   const ncscale_e scale = vopts ? vopts->scaling : NCSCALE_NONE;
   ncblitter_e blitter;
   if(!vopts || vopts->blitter == NCBLIT_DEFAULT){
-    blitter = ncvisual_default_blitter(nc, scale);
+    blitter = ncvisual_media_defblitter(nc, scale);
   }else{
     blitter = vopts->blitter;
   }
@@ -33,16 +33,16 @@ auto ncvisual_geom(const notcurses* nc, const ncvisual* n,
     x = &fauxx;
   }
   if(n){
-    if(scale == NCSCALE_NONE){
+    if(scale == NCSCALE_NONE || scale == NCSCALE_NONE_HIRES){
       *y = n->rows;
-      *x = n->cols;
+      *x = n->cols;// * encoding_x_scale(bset);
     }else{
       int rows = vopts->n ? ncplane_dim_y(vopts->n) : ncplane_dim_y(nc->stdplane);
       int cols = vopts->n ? ncplane_dim_x(vopts->n) : ncplane_dim_x(nc->stdplane);
       *y = rows * encoding_y_scale(bset);
       *x = cols * encoding_x_scale(bset);
     }
-    if(scale == NCSCALE_SCALE){
+    if(scale == NCSCALE_SCALE || scale == NCSCALE_SCALE_HIRES){
       scale_visual(n, y, x);
     }
   }
@@ -406,14 +406,14 @@ auto ncvisual_render(notcurses* nc, ncvisual* ncv,
   ncplane* n = nullptr;
 //fprintf(stderr, "INPUT N: %p\n", vopts ? vopts->n : nullptr);
   if((n = (vopts ? vopts->n : nullptr)) == nullptr){ // create plane
-    if(!vopts || vopts->scaling == NCSCALE_NONE){
-      dispcols = ncv->cols;
-      disprows = ncv->rows;
+    if(!vopts || vopts->scaling == NCSCALE_NONE || vopts->scaling == NCSCALE_NONE_HIRES){
+      dispcols = ncv->cols;// * encoding_x_scale(bset);
+      disprows = ncv->rows;// * encoding_y_scale(bset);
     }else{
       notcurses_term_dim_yx(nc, &disprows, &dispcols);
       dispcols *= encoding_x_scale(bset);
       disprows *= encoding_y_scale(bset);
-      if(vopts->scaling == NCSCALE_SCALE){
+      if(vopts->scaling == NCSCALE_SCALE || vopts->scaling == NCSCALE_SCALE_HIRES){
         scale_visual(ncv, &disprows, &dispcols);
       }
     }
@@ -434,16 +434,16 @@ auto ncvisual_render(notcurses* nc, ncvisual* ncv,
     placey = 0;
     placex = 0;
   }else{
-    if(!vopts || vopts->scaling == NCSCALE_NONE){
-      dispcols = ncv->cols;
-      disprows = ncv->rows;
+    if(!vopts || vopts->scaling == NCSCALE_NONE || vopts->scaling == NCSCALE_NONE_HIRES){
+      dispcols = ncv->cols;// * encoding_x_scale(bset);
+      disprows = ncv->rows;// * encoding_y_scale(bset);
     }else{
       ncplane_dim_yx(n, &disprows, &dispcols);
       dispcols *= encoding_x_scale(bset);
       disprows *= encoding_y_scale(bset);
       disprows -= placey;
       dispcols -= placex;
-      if(vopts->scaling == NCSCALE_SCALE){
+      if(vopts->scaling == NCSCALE_SCALE || vopts->scaling == NCSCALE_SCALE_HIRES){
         scale_visual(ncv, &disprows, &dispcols);
       }
     }
