@@ -95,7 +95,7 @@ TEST_CASE("Wide") {
       wchar_t w;
       CHECK(0 < mbtowc(&w, cell_extended_gcluster(n_, &tcell), MB_CUR_MAX));
       if(wcwidth(w) == 2){
-        CHECK(CELL_WIDEASIAN_MASK == testcell.channels);
+        CHECK(2 == testcell.width);
         ++x;
       }else{
         CHECK(0 == testcell.channels);
@@ -257,7 +257,7 @@ TEST_CASE("Wide") {
   }
 
   SUBCASE("RenderWides") {
-    CHECK(0 <= ncplane_putstr(n_, "\xe5\xbd\xa2\xe5\x85\xa8"));
+    CHECK(0 <= ncplane_putstr(n_, "\u5f62\u5168"));
     nccell c = CELL_TRIVIAL_INITIALIZER;
     ncplane_at_yx_cell(n_, 0, 0, &c);
     CHECK(cell_double_wide_p(&c));
@@ -270,16 +270,19 @@ TEST_CASE("Wide") {
     ncplane_at_yx_cell(n_, 0, 4, &c);
     CHECK(!cell_double_wide_p(&c));
     CHECK(0 == notcurses_render(nc_));
-    notcurses_at_yx(nc_, 0, 0, &c.stylemask, &c.channels);
-    CHECK(0 != (c.channels & 0x8000000080000000ull));
-    notcurses_at_yx(nc_, 0, 1, &c.stylemask, &c.channels);
-    CHECK(0 != (c.channels & 0x8000000080000000ull));
-    notcurses_at_yx(nc_, 0, 2, &c.stylemask, &c.channels);
-    CHECK(0 != (c.channels & 0x8000000080000000ull));
-    notcurses_at_yx(nc_, 0, 3, &c.stylemask, &c.channels);
-    CHECK(0 != (c.channels & 0x8000000080000000ull));
-    notcurses_at_yx(nc_, 0, 4, &c.stylemask, &c.channels);
-    CHECK(!(c.channels & 0x8000000080000000ull));
+    auto egc = notcurses_at_yx(nc_, 0, 0, &c.stylemask, &c.channels);
+    REQUIRE(nullptr != egc);
+    CHECK(0 == strcmp("\u5f62", egc));
+    egc = notcurses_at_yx(nc_, 0, 1, &c.stylemask, &c.channels);
+    REQUIRE(nullptr != egc);
+    CHECK(0 == strcmp("", egc));
+    egc = notcurses_at_yx(nc_, 0, 2, &c.stylemask, &c.channels);
+    REQUIRE(nullptr != egc);
+    CHECK(0 == strcmp("\u5168", egc));
+    egc = notcurses_at_yx(nc_, 0, 3, &c.stylemask, &c.channels);
+    REQUIRE(nullptr != egc);
+    egc = notcurses_at_yx(nc_, 0, 4, &c.stylemask, &c.channels);
+    REQUIRE(nullptr != egc);
   }
 
   // If an ncplane is moved atop the right half of a wide glyph, the entire
@@ -460,43 +463,34 @@ TEST_CASE("Wide") {
     uint16_t stylemask;
     uint64_t channels;
     char* egc;
-    uint64_t widechans = ncplane_channels(n_) | CELL_WIDEASIAN_MASK;
-    uint64_t narchans = ncplane_channels(topp);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 0, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "六"));
-    CHECK(widechans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 1, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 2, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "六"));
-    CHECK(widechans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 3, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 4, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "a"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 5, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "b"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 6, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "c"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 7, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "d"));
-    CHECK(narchans == channels);
     free(egc);
     CHECK(0 == ncplane_move_yx(topp, 0, 3));
     CHECK(0 == notcurses_render(nc_));
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 0, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "六"));
-    CHECK(widechans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 1, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
@@ -506,19 +500,15 @@ TEST_CASE("Wide") {
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 3, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "a"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 4, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "b"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 5, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "c"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 6, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "d"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 7, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
@@ -527,30 +517,24 @@ TEST_CASE("Wide") {
     CHECK(0 == notcurses_render(nc_));
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 0, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "六"));
-    CHECK(widechans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 1, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 2, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "a"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 3, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "b"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 4, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "c"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 5, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "d"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 6, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "六"));
-    CHECK(widechans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 7, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
@@ -562,26 +546,21 @@ TEST_CASE("Wide") {
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 1, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "a"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 2, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "b"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 3, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "c"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 4, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "d"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 5, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 6, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "六"));
-    CHECK(widechans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 7, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
@@ -590,30 +569,24 @@ TEST_CASE("Wide") {
     CHECK(0 == notcurses_render(nc_));
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 0, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "a"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 1, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "b"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 2, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "c"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 3, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "d"));
-    CHECK(narchans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 4, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "六"));
-    CHECK(widechans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 5, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 6, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, "六"));
-    CHECK(widechans == channels);
     free(egc);
     REQUIRE((egc = notcurses_at_yx(nc_, 0, 7, &stylemask, &channels)));
     CHECK(0 == strcmp(egc, ""));
